.. _installation:

Installation
============

The recommended way to install ``mccli`` is with ``pip``:

.. code-block:: bash

   pip install mccli

This will ensure that the stable version is fetched from pip, rather
than the development version.

Installing the development version
----------------------------------

The development version of mccli can be installed from the ``master`` branch
of the `GitHub mccli repository <https://github.com/dianagudu/mccli>`_ and
can be installed as follows (note the ``-e`` switch to install it in editable
or "develop mode"):

.. code-block:: bash

   git clone https://github.com/dianagudu/mccli
   cd mccli
   pip install -e .

